@@ -1,7 +1,7 @@
 use std::sync::Arc;
 
 use futures_util::stream::Stream;
-use tracing::{debug, error, trace};
+use tracing::{debug, error, trace, instrument};
 use once_cell::sync::Lazy;
 use futures_util::future::{Either, err};
 use futures_util::stream::{StreamExt, once, iter};
@@ -15,13 +15,12 @@ use dataplane::fetch::FetchPartition;
 use dataplane::fetch::FetchableTopic;
 use dataplane::fetch::FetchablePartitionResponse;
 use dataplane::record::RecordSet;
-use dataplane::record::DefaultRecord;
-use dataplane::batch::DefaultBatch;
+use dataplane::record::Record as DefaultRecord;
+use dataplane::batch::Batch;
 use fluvio_types::event::offsets::OffsetPublisher;
 
 use crate::FluvioError;
 use crate::offset::Offset;
-use crate::sockets::SerialFrame;
 use crate::spu::SpuPool;
 
 /// An interface for consuming events from a particular partition
@@ -296,7 +295,7 @@ impl PartitionConsumer {
     ) -> Result<impl Stream<Item = Result<Record, FluvioError>>, FluvioError> {
         let stream = self.stream_batches_with_config(offset, config).await?;
         let flattened =
-            stream.flat_map(|result: Result<DefaultBatch, _>| match result {
+            stream.flat_map(|result: Result<Batch, _>| match result {
                 Err(e) => Either::Right(once(err(e))),
                 Ok(batch) => {
                     let base_offset = batch.base_offset;
@@ -343,7 +342,7 @@ impl PartitionConsumer {
         &self,
         offset: Offset,
         config: ConsumerConfig,
-    ) -> Result<impl Stream<Item = Result<DefaultBatch, FluvioError>>, FluvioError> {
+    ) -> Result<impl Stream<Item = Result<Batch, FluvioError>>, FluvioError> {
         let stream = self.request_stream(offset, config).await?;
         let flattened = stream.flat_map(|batch_result: Result<DefaultStreamFetchResponse, _>| {
             let response: DefaultStreamFetchResponse = match batch_result {
@@ -369,6 +368,7 @@ impl PartitionConsumer {
     /// Creates a stream of `DefaultStreamFetchResponse` for older consumers who rely
     /// on the internal structure of the fetch response. New clients should use the
     /// `stream` and `stream_with_config` methods.
+    #[instrument(skip(self, config))]
     async fn request_stream(
         &self,
         offset: Offset,
@@ -381,18 +381,15 @@ impl PartitionConsumer {
         use fluvio_protocol::api::Request;
 
         let replica = ReplicaKey::new(&self.topic, self.partition);
-        debug!(
-            "starting fetch log once: {:#?} from replica: {}",
-            offset, &replica,
-        );
 
         let mut serial_socket = self.pool.create_serial_socket(&replica).await?;
-        trace!("created serial socket {}", serial_socket);
 
         let start_absolute_offset = offset
             .to_absolute(&mut serial_socket, &self.topic, self.partition)
             .await?;
 
+        debug!(start_absolute_offset);
+
         let mut stream_request = DefaultStreamFetchRequest {
             topic: self.topic.to_owned(),
             partition: self.partition,
